Welcome to Thoth's adviser documentation
----------------------------------------

Thoth's adviser is a recommendation engine for Python applications.

This documentation corresponds to a component called "adviser". Sources can be
found on `GitHub <https://github.com/thoth-station/adviser>`_.

See `thoth-station <https://thoth-station.ninja>`_ website and `Thoth-Station
organization on GitHub <https://github.com/thoth-station>`_.

Introductory sections
=====================

.. toctree::
   :maxdepth: 1

   introduction
   integration
   compatibility
   developers_guide
   architecture
   deployment


Resolver and stack resolution pipeline
======================================

.. toctree::
   :maxdepth: 1

   pipeline
   resolver
   predictor


Pipeline units
==============

.. toctree::
   :maxdepth: 1

   unit
   boots
   sieves
   steps
   strides
   wraps


Predictors
==========

.. toctree::
   :maxdepth: 1

   predictors/sampling
   predictors/hill_climbing
   predictors/monte_carlo
   predictors/annealing
   predictors/rl


Other functionality provided by thoth-adviser implementation
============================================================

.. toctree::
   :maxdepth: 1

   dependency_monkey
   provenance_checks
   performance


Crossroad
=========

* `Documentation for thamos <../thamos>`_
* `Documentation for thoth-analyzer <../analyzer>`_
* `Documentation for thoth-common <../common>`_
* `Documentation for thoth-lab <../lab>`_
* `Documentation for thoth-package-analyzer <../package-analyzer>`_
* `Documentation for thoth-package-extract <../package-extract>`_
* `Documentation for thoth-python <../python>`_
* `Documentation for thoth-solver <../solver>`_
* `Documentation for thoth-storages <../storages>`_
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. toctree::
   :maxdepth: 3

   thoth.adviser


This documentation corresponds to implementation in version |version|,
documentation was generated on |today|.
